<?php

namespace EuKit\Base;

use EuKit\Base\Interfaces\ViewModel;
use EuKit\Base\BasePageTemplate;
use Infomaker\Everyware\Base\Models\Post;
use Infomaker\Everyware\Base\OpenContent\OpenContentProvider;
use OcArticle;

/**
 * Class ArticlePageTemplate
 * @package EuKit\Base
 */
class ArticlePageTemplate extends BasePageTemplate implements ViewModel
{
    /**
     * @var NewsMLArticle
     */
    private $article;

    public function __construct(NewsMLArticle $article)
    {
        $this->initViewData();

        $this->article = $article;
        $articleBody = $this->article->getParsedBody();
        $articleBodyPresentation = new ArticleBodyPresentation($this->article);

        $this->mergeViewData($this->article->toArray());
        $this->mergeViewData(['teaserImage' => $this->getTeaserImage()]);
        $this->mergeViewData(['body' => $articleBody->generateContent($articleBodyPresentation)]);
        $this->mergeViewData(['relatedArticles' => $articleBody->allOfType('x-im/articlex')]);
        $this->mergeViewData(['authors' => $this->article->getAuthors()->toArray()]);
    }

    protected function getTeaserImage()
    {
        $articleTeaser = $this->article->getNewsMLTeaser();
        $image = $articleTeaser ? $articleTeaser->getImage() : null;

        if ($image !== null) {
            $image->set('text', $articleTeaser->title);
            $image = new Image($image);
        }

        return $image ? $image->getViewData() : null;
    }

    public static function createFromPost(Post $post)
    {
        $uuid = $post->getMeta('oc_uuid');

        $provider = OpenContentProvider::setup();
        $provider->setPropertyMap('Article');
        $article = $provider->getObject($uuid);

        if ($article instanceof OcArticle) {
            return new static(NewsMLArticle::createFromOcArticle($article));
        }

        return new static(new NewsMLArticle($article));
    }
}
